@@ -14,14 +14,49 @@ __license__ = "See LICENSE.restfulie for details"
 from contextlib import contextmanager
 from functools import wraps
 
-__all__ = ['Client']
+__all__ = ['Client', 'Extend']
 
 # local submodule requirements
 from .credentials import Credentials
 
+
+class Extend(type):
+    """
+    Allow Ad-hoc inheritance. See
+    http://code.activestate.com/recipes/412717-extending-classes/ for
+    details
+    """
+
+    clients = {}
+
+    #pylint: disable-msg=W0613
+    def __new__(mcs, name, bases, dct):
+        prev = Extend.clients[name]
+        del dct['__module__']
+        del dct['__metaclass__']
+        for key, value in dct.iteritems():
+            if key == "__doc__":
+                continue
+            setattr(prev, key, value)
+        return prev
+
+        
+class ClientMeta(type):
+    """
+    Simple metaclass to make client subclasses discoverable by
+    Extend metaclass
+    """
+    def __init__(mcs, name, bases, dct):
+        super(ClientMeta, mcs).__init__(name, bases, dct)
+        assert name not in Extend.clients
+        Extend.clients[name] = mcs
+
+            
 class Client(object):
     """Base class to implement a remote API"""
 
+    __metaclass__ = ClientMeta
+
     def __init__(self, credentials=None):
         self._config = credentials or Credentials()
 
@@ -35,41 +70,3 @@ class Client(object):
         """Get credentials element"""
         return self._config
 
-    @property
-    def write_enabled(self):
-        """Check if config has valid credentials. Return false
-        otherwise"""
-        raise NotImplementedError
-
-
-class Extend(type):
-    """
-    Allow Ad-hoc inheritance. See
-    http://code.activestate.com/recipes/412717-extending-classes/ for
-    details
-    """
-
-    #pylint: disable-msg=W0613
-    def __new__(mcs, name, bases, dct):
-        prev = globals()[name]
-        del dct['__module__']
-        del dct['__metaclass__']
-        for key, value in dct.iteritems():
-            if key == "__doc__":
-                continue
-            setattr(prev, key, value)
-        return prev
-
-
-def validate(table):
-    """Check that required attributes are present on method invoke"""
-    #pylint: disable-msg=C0111
-    def wrap_f(func):
-        def new_func(instance, action, args, callback=None):
-            if action not in getattr(instance, table):
-                raise AttributeError("Missing action '%s'" % action)
-            return func(instance, action, args, callback)
-        return wraps(func)(new_func)
-    return wrap_f
-
-
