@@ -24,14 +24,14 @@ class Request(object):
     def __init__(self, config):
         self._config = config
 
-    def __call__(self, callback=None, params=None, **payload):
+    def __call__(self, body=None, params=None, callback=None):
         """
         Perform the request.The optional payload argument is sent to
         the server
         """
         env = {
             'params'  : params,
-            'payload' : payload, 
+            'payload' : body,
             }
 
         procs = list(self._config.processors)
