@@ -28,11 +28,14 @@ class ResourceError(Exception):
 class Resource(object):
     """Prepares a connection. only get a pika connection is lazy created"""
 
+    def __getitem__(self, key):
+        raise NotImplementedError
+        
     def links(self):
         """Returns a list of all links."""
         raise NotImplementedError
 
-    def link(self, rel):
+    def link(self, rel, default=None):
         """Return a Link with rel."""
         raise NotImplementedError
 
